$ProcessGlobalConfigSettings class abstract

Class that represents the settings used to configure the PlatformProcessGlobalConfig.

Officially Supported Platforms/Implementations: Android native WebView

Annotations
  • @Zorphy.new(kind: ZorphyKind.valueObject, generateJson: true, generateCompareTo: true)

Properties

dataDirectorySuffix → String?
The directory name suffix to be used for the current process. Must not contain a path separator and should not be empty.
no setter
directoryBasePaths → ProcessGlobalConfigDirectoryBasePaths?
Set the base directories that WebView will use for the current process. If this method is not used, WebView uses the default base paths defined by the Android framework.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited