ActionModeMenuItem enum
Class used to disable the action mode menu items.
Values
- MENU_ITEM_NONE → const ActionModeMenuItem
-
No menu items should be disabled.
- MENU_ITEM_SHARE → const ActionModeMenuItem
-
Disable menu item "Share".
- MENU_ITEM_WEB_SEARCH → const ActionModeMenuItem
-
Disable menu item "Web Search".
- MENU_ITEM_PROCESS_TEXT → const ActionModeMenuItem
-
Disable all the action mode menu items for text processing.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ActionModeMenuItem> - A constant List of the values in this enum, in order of their declaration.