Disposable class abstract
- Implementers
- ChannelController
- PlatformChromeSafariBrowser
- PlatformCookieManager
- PlatformFindInteractionController
- PlatformHeadlessInAppWebView
- PlatformHttpAuthCredentialDatabase
- PlatformInAppBrowser
- PlatformInAppWebViewController
- PlatformInAppWebViewWidget
- PlatformPrintJobController
- PlatformProcessGlobalConfig
- PlatformProxyController
- PlatformPullToRefreshController
- PlatformServiceWorkerController
- PlatformStorage
- PlatformTracingController
- PlatformWebAuthenticationSession
- PlatformWebMessageChannel
- PlatformWebMessageListener
- PlatformWebStorage
- PlatformWebStorageManager
- PlatformWebViewEnvironment
- PlatformWebViewFeature
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
{bool isKeepAlive = false}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited