InAppBrowserMenuItem class

Class that represents a menu item of the InAppBrowser.

Constructors

InAppBrowserMenuItem({required int id, required String title, dynamic icon, Color_? iconColor, int? order, bool showAsAction = false, void onClick()?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ dynamic
The menu item icon. It can be a Uint8List, an AndroidResource or a UIImage.
getter/setter pair
iconColor ↔ Color_?
The menu item icon color.
getter/setter pair
id ↔ int
The menu item id.
getter/setter pair
onClick ↔ void Function()?
Callback function to be invoked when the menu item is clicked.
getter/setter pair
order ↔ int?
The menu item order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAsAction ↔ bool
Whether the menu item should be shown as an action.
getter/setter pair
title ↔ String
The menu item title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic>? map) → InAppBrowserMenuItem?
Gets a possible InAppBrowserMenuItem instance from a Map value.
fromMap(Map<String, dynamic>? map) → InAppBrowserMenuItem?
Gets a possible InAppBrowserMenuItem instance from a Map value.