InAppWebViewHitTestResult class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true, checked: true)

Properties

extra → String?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → InAppWebViewHitTestResultType?
final

Methods

copyWith({InAppWebViewHitTestResultType? type, String? extra}) → InAppWebViewHitTestResult
copyWithInAppWebViewHitTestResult({InAppWebViewHitTestResultType? type, String? extra}) → InAppWebViewHitTestResult
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithInAppWebViewHitTestResult([InAppWebViewHitTestResultPatch? patchInput]) → InAppWebViewHitTestResult
toJson() → Map<String, dynamic>

Available on InAppWebViewHitTestResult, provided by the InAppWebViewHitTestResultSerialization extension

toJsonLean() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override