InAppWebViewRect class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true, checked: true)

Constructors

InAppWebViewRect({required double x, required double y, required double width, required double height})
InAppWebViewRect.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final
x → double
final
y → double
final

Methods

copyWith({double? x, double? y, double? width, double? height}) → InAppWebViewRect
copyWithInAppWebViewRect({double? x, double? y, double? width, double? height}) → InAppWebViewRect
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithInAppWebViewRect([InAppWebViewRectPatch? patchInput]) → InAppWebViewRect
toJson() → Map<String, dynamic>

Available on InAppWebViewRect, provided by the InAppWebViewRectSerialization extension

toJsonLean() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override