JsConfirmResponse class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true, checked: true)

Constructors

JsConfirmResponse({String? message, String? confirmButtonTitle, String? cancelButtonTitle, bool? handledByClient, JsConfirmResponseAction? action})
JsConfirmResponse.fromJson(Map<String, dynamic> json)
factory

Properties

action → JsConfirmResponseAction?
final
cancelButtonTitle → String
final
confirmButtonTitle → String
final
handledByClient → bool
final
hashCode → int
The hash code for this object.
no setteroverride
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? message, String? confirmButtonTitle, String? cancelButtonTitle, bool? handledByClient, JsConfirmResponseAction? action}) → JsConfirmResponse
copyWithJsConfirmResponse({String? message, String? confirmButtonTitle, String? cancelButtonTitle, bool? handledByClient, JsConfirmResponseAction? action}) → JsConfirmResponse
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithJsConfirmResponse([JsConfirmResponsePatch? patchInput]) → JsConfirmResponse
toJson() → Map<String, dynamic>

Available on JsConfirmResponse, provided by the JsConfirmResponseSerialization extension

toJsonLean() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override