LayoutInDisplayCutoutMode enum

Class representing the share state that should be applied to the custom tab.

Inheritance
Available extensions

Values

DEFAULT → const LayoutInDisplayCutoutMode

With this default setting, content renders into the cutout area when displayed in portrait mode, but content is letterboxed when displayed in landscape mode.

NOTE: available on Android 28+.

SHORT_EDGES → const LayoutInDisplayCutoutMode

Content renders into the cutout area in both portrait and landscape modes.

NOTE: available on Android 28+.

NEVER → const LayoutInDisplayCutoutMode

Content never renders into the cutout area.

NOTE: available on Android 28+.

ALWAYS → const LayoutInDisplayCutoutMode

The window is always allowed to extend into the DisplayCutout areas on the all edges of the screen.

NOTE: available on Android 30+.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<LayoutInDisplayCutoutMode>
A constant List of the values in this enum, in order of their declaration.