PlatformInAppBrowserCreationParams class

Object specifying creation parameters for creating a PlatformInAppBrowser.

Platform specific implementations can add additional fields by extending this class.

Annotations

Constructors

PlatformInAppBrowserCreationParams({ContextMenu? contextMenu, PlatformPullToRefreshController? pullToRefreshController, PlatformFindInteractionController? findInteractionController, UnmodifiableListView<UserScript>? initialUserScripts, int? windowId, PlatformWebViewEnvironment? webViewEnvironment})
Used by the platform implementation to create a new PlatformInAppBrowser.
const

Properties

contextMenu → ContextMenu?
Context menu used by the browser. It should be set before opening the browser.
final
findInteractionController → PlatformFindInteractionController?
Represents the find interaction feature controller.
final
hashCode → int
The hash code for this object.
no setterinherited
initialUserScripts → UnmodifiableListView<UserScript>?
Initial list of user scripts to be loaded at start or end of a page loading.
final
pullToRefreshController → PlatformPullToRefreshController?
Represents the pull-to-refresh feature controller.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webViewEnvironment → PlatformWebViewEnvironment?
Used to create the PlatformInAppBrowser using the specified environment.
final
windowId → int?
The window id of a CreateWindowAction.windowId.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited