ProcessGlobalConfigSettingsPatch class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
patchMap
→ Map<
ProcessGlobalConfigSettings$, dynamic> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyTo(
ProcessGlobalConfigSettings entity) → ProcessGlobalConfigSettings - Applies this patch to the given entity
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toPatch(
) → Map< ProcessGlobalConfigSettings$, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
withDataDirectorySuffix(
String? value) → ProcessGlobalConfigSettingsPatch -
withDirectoryBasePaths(
ProcessGlobalConfigDirectoryBasePaths? value) → ProcessGlobalConfigSettingsPatch -
withDirectoryBasePathsPatch(
ProcessGlobalConfigDirectoryBasePathsPatch patch) → ProcessGlobalConfigSettingsPatch -
withDirectoryBasePathsPatchFunc(
ProcessGlobalConfigDirectoryBasePathsPatch patch(ProcessGlobalConfigDirectoryBasePathsPatch)) → ProcessGlobalConfigSettingsPatch
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited