PullToRefreshSettings class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true, checked: true)

Constructors

PullToRefreshSettings({bool? enabled, Color? color, Color? backgroundColor, int? distanceToTriggerSync, int? slingshotDistance, PullToRefreshSize? size, AttributedString? attributedTitle})
PullToRefreshSettings.fromJson(Map<String, dynamic> json)
factory

Properties

attributedTitle → AttributedString?
final
backgroundColor → Color?
final
color → Color?
final
distanceToTriggerSync → int?
final
enabled → bool?
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PullToRefreshSize?
final
slingshotDistance → int?
final

Methods

copyWith({bool? enabled, Color? color, Color? backgroundColor, int? distanceToTriggerSync, int? slingshotDistance, PullToRefreshSize? size, AttributedString? attributedTitle}) → PullToRefreshSettings
copyWithPullToRefreshSettings({bool? enabled, Color? color, Color? backgroundColor, int? distanceToTriggerSync, int? slingshotDistance, PullToRefreshSize? size, AttributedString? attributedTitle}) → PullToRefreshSettings
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithPullToRefreshSettings([PullToRefreshSettingsPatch? patchInput]) → PullToRefreshSettings
toJson() → Map<String, dynamic>

Available on PullToRefreshSettings, provided by the PullToRefreshSettingsSerialization extension

toJsonLean() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override