SslCertificate class

Represents an SSL certificate.

Constructors

SslCertificate({SslCertificateDName? issuedBy, SslCertificateDName? issuedTo, DateTime? validNotAfterDate, DateTime? validNotBeforeDate, X509Certificate? x509Certificate})

Properties

hashCode → int
The hash code for this object.
no setterinherited
issuedBy ↔ SslCertificateDName?
Name of the entity this certificate is issued by.
getter/setter pair
issuedTo ↔ SslCertificateDName?
Name of the entity this certificate is issued to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validNotAfterDate ↔ DateTime?
Not-after date from the validity period.
getter/setter pair
validNotBeforeDate ↔ DateTime?
Not-before date from the validity period.
getter/setter pair
x509Certificate ↔ X509Certificate?
The original source certificate, if available.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap() → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map) → SslCertificate?
Gets a possible SslCertificate instance from a Map value.