WebStorageItem class

Available extensions
Annotations
  • @JsonSerializable.new(explicitToJson: true, checked: true)

Constructors

WebStorageItem({String? key, dynamic value})
WebStorageItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
key → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
final

Methods

copyWith({String? key, dynamic value}) → WebStorageItem
copyWithWebStorageItem({String? key, dynamic value}) → WebStorageItem
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patchWithWebStorageItem([WebStorageItemPatch? patchInput]) → WebStorageItem
toJson() → Map<String, dynamic>

Available on WebStorageItem, provided by the WebStorageItemSerialization extension

toJsonLean() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override