zikzak_inappwebview_platform_interface
library
Classes
-
$AndroidProxySettings
-
-
$IOSProxySettings
-
-
$ProcessGlobalConfigDirectoryBasePaths
-
Class that represents the settings used to configure the ProcessGlobalConfigSettings.directoryBasePaths.
-
$ProcessGlobalConfigSettings
-
Class that represents the settings used to configure the PlatformProcessGlobalConfig.
-
$WebViewAssetLoader
-
Helper class to load local files including application's static assets and resources using http(s):// URLs inside a
WebView class.
Loading local files using web-like URLs instead of file:// is desirable as it is compatible with the Same-Origin policy.
-
ActivityButton
-
-
AjaxRequest
-
-
AjaxRequestEvent
-
-
Class that represents the HTTP headers of an AjaxRequest.
-
AndroidProxySettings
-
-
AndroidProxySettingsFields
-
Field descriptors for AndroidProxySettings query construction
-
AndroidProxySettingsPatch
-
-
AndroidResource
-
-
AndroidWebViewInsets
-
Window-inset types that an Android WebView can be told to ignore when
laying out web content.
-
ASN1DERDecoder
-
-
ASN1DEREncoder
-
-
ASN1DistinguishedNames
-
-
ASN1Identifier
-
-
ASN1IdentifierClass
-
-
ASN1IdentifierTagNumber
-
-
ASN1Object
-
-
AttributedString
-
-
AuthorityInfoAccess
-
-
AuthorityInfoAccessExtension
-
Recognition for Authority Info Access Extension (1.3.6.1.5.5.7.1.1)
-
AuthorityKeyIdentifierExtension
-
Recognition for Authority Key Identifier Extension (2.5.29.35)
-
BasicConstraintExtension
-
Recognition for Basic Constraint Extension (2.5.29.19)
-
CallAsyncJavaScriptResult
-
-
CertificatePoliciesExtension
-
Recognition for Certificate Policies Extension (2.5.29.32)
-
CertificatePolicy
-
-
CertificatePolicyQualifier
-
-
ChromeSafariBrowserActionButton
-
Class that represents an action button of the Chrome Custom Tabs.
-
Class that represents a menu item of the Chrome Custom Tabs.
-
ChromeSafariBrowserSecondaryToolbar
-
Class that represents the secondary toolbar of the Chrome Custom Tabs.
-
ChromeSafariBrowserSecondaryToolbarClickableID
-
Class that represents a clickable ID of the secondary toolbar.
-
ChromeSafariBrowserSettings
-
-
ClientCertChallenge
-
Class that represents the challenge of the PlatformWebViewCreationParams.onReceivedClientCertRequest event.
It provides all the information about the challenge.
-
ClientCertResponse
-
-
Color_
-
-
ConsoleMessage
-
-
ContentBlocker
-
Class that represents a set of rules to use block content in the browser window.
-
ContentBlockerAction
-
Action associated to the trigger. The action tells to the WebView what to do when the trigger is matched.
When a trigger matches a resource, the browser queues the associated action for execution.
The WebView evaluates all the triggers, it executes the actions in order.
When a domain matches a trigger, all rules after the triggered rule that specify the same action are skipped.
Group the rules with similar actions together to improve performance.
-
ContentBlockerTrigger
-
Trigger of the content blocker. The trigger tells to the WebView when to perform the corresponding action.
A trigger dictionary must include an ContentBlockerTrigger.urlFilter, which specifies a pattern to match the URL against.
The remaining properties are optional and modify the behavior of the trigger.
For example, you can limit the trigger to specific domains or have it not apply when a match is found on a specific domain.
-
ContentWorld
-
Class that represents an object that defines a scope of execution for JavaScript code and which you use to prevent conflicts between different scripts.
-
Class that represents the context menu of a WebView.
-
Class that represents a menu item of a ContextMenu.
-
-
Cookie
-
-
CreateWindowAction
-
-
CRLDistributionPointsExtension
-
-
CSSLinkHtmlTagAttributes
-
-
CustomSchemeResponse
-
-
DebugLoggingSettings
-
Class that represents the debug logging settings.
-
DefaultInAppLocalhostServer
-
This class allows you to create a simple server on
http://localhost:[port]/
in order to be able to load your assets file on a local server.
The default port value is 8080.
-
DefaultInAppLocalhostServerCreationParams
-
Object specifying creation parameters for creating a DefaultInAppLocalhostServer.
-
Disposable
-
-
DomainBudget
-
Per-domain capture budget.
-
DownloadStartRequest
-
-
Favicon
-
-
FetchRequest
-
-
FetchRequestCredential
-
Class that is an interface for FetchRequestCredentialDefault, FetchRequestFederatedCredential and FetchRequestPasswordCredential classes.
-
FetchRequestCredentialDefault
-
Class that represents the default credentials used by an FetchRequest.
-
FetchRequestFederatedCredential
-
Class that represents a FederatedCredential type of credentials.
-
FetchRequestPasswordCredential
-
Class that represents a PasswordCredential type of credentials.
-
FindSession
-
-
FrameInfo
-
-
GeolocationPermissionShowPromptResponse
-
-
HttpAuthenticationChallenge
-
Class that represents the challenge of the PlatformWebViewCreationParams.onReceivedHttpAuthRequest event.
It provides all the information about the challenge.
-
HttpAuthResponse
-
-
IdGenerator
-
-
InAppBrowserClassSettings
-
Class that represents the settings that can be used for an
InAppBrowser instance.
-
Class that represents a menu item of the InAppBrowser.
-
InAppBrowserSettings
-
-
InAppWebViewControllerKeepAliveProps
-
Used internally to save and restore PlatformInAppWebViewController properties
for the keep alive feature.
-
InAppWebViewHitTestResult
-
-
InAppWebViewInitialData
-
-
InAppWebViewKeepAlive
-
Class used to keep alive a PlatformInAppWebViewWidget.
-
InAppWebViewPlatform
-
Interface for a platform implementation of a WebView.
-
InAppWebViewRect
-
-
InAppWebViewSettings
-
-
IOSProxySettings
-
-
IOSProxySettingsFields
-
Field descriptors for IOSProxySettings query construction
-
IOSProxySettingsPatch
-
-
IWebMessagePort
-
-
JsAlertRequest
-
-
JsAlertResponse
-
-
JsBeforeUnloadRequest
-
-
JsBeforeUnloadResponse
-
-
JsConfirmRequest
-
-
JsConfirmResponse
-
-
JsPromptRequest
-
-
JsPromptResponse
-
-
KeyUsage
-
-
LoadedResource
-
-
LoginRequest
-
-
MetaTag
-
-
MetaTagAttribute
-
-
NavigationAction
-
-
NavigationResponse
-
-
NetworkCaptureController
-
Controller that accumulates network capture data for bulk retrieval.
-
NetworkEntry
-
A complete captured request-response pair.
-
NetworkRequest
-
Represents an outgoing network request captured by the Network Capture API.
-
NetworkResponse
-
Represents a network response (status + headers) captured by the
Network Capture API, before the body has been fully read.
-
NetworkResponseBody
-
Represents a fully captured response body.
-
OID
-
-
PDFConfiguration
-
-
PermissionRequest
-
-
PermissionResponse
-
-
PlatformAssetsPathHandler
-
Handler class to open a file from assets directory in the application APK.
-
PlatformAssetsPathHandlerCreationParams
-
Object specifying creation parameters for creating a PlatformAssetsPathHandler.
-
PlatformChromeSafariBrowser
-
Class that provides a visible standard interface for browsing the web.
It presents a self-contained web interface inside your app.
-
PlatformChromeSafariBrowserCreationParams
-
Object specifying creation parameters for creating a PlatformChromeSafariBrowser.
-
PlatformChromeSafariBrowserEvents
-
-
PlatformCookieDelegate
-
Delegate for cookie-management methods scoped to a single
PlatformInAppWebViewController.
-
PlatformCookieManager
-
Class that implements a singleton object (shared instance) which manages the cookies used by WebView instances.
On Android, it is implemented using CookieManager.
On iOS, it is implemented using WKHTTPCookieStore.
-
PlatformCookieManagerCreationParams
-
Object specifying creation parameters for creating a PlatformCookieManager.
-
PlatformCustomPathHandler
-
Custom handler class used to implement a custom logic to open a file.
-
PlatformCustomPathHandlerCreationParams
-
Object specifying creation parameters for creating a PlatformCustomPathHandler.
-
PlatformFindInteractionController
-
This class represents the controller used by the
WebView to add
text-finding capabilities, such as the "Find on page" feature.
-
PlatformFindInteractionControllerCreationParams
-
Object specifying creation parameters for creating a PlatformFindInteractionController.
-
PlatformHeadlessInAppWebView
-
Class that represents a WebView in headless mode.
It can be used to run a WebView in background without attaching an
InAppWebView to the widget tree.
-
PlatformHeadlessInAppWebViewCreationParams
-
Object specifying creation parameters for creating a PlatformInAppWebViewWidget.
-
PlatformHttpAuthCredentialDatabase
-
Class that implements a singleton object (shared instance) which manages the shared HTTP auth credentials cache.
On iOS and MacOS, this class uses the URLCredentialStorage class.
On Android, this class has a custom implementation using
android.database.sqlite.SQLiteDatabase because
WebViewDatabase
doesn't offer the same functionalities as iOS URLCredentialStorage.
-
PlatformHttpAuthCredentialDatabaseCreationParams
-
Object specifying creation parameters for creating a PlatformHttpAuthCredentialDatabase.
-
PlatformInAppBrowser
-
This class represents a native WebView displayed on top of the Flutter App,
so it's not integrated into the Flutter widget tree.
It uses the native WebView of the platform.
The webViewController field can be used to access the PlatformInAppWebViewController API.
-
PlatformInAppBrowserCreationParams
-
Object specifying creation parameters for creating a PlatformInAppBrowser.
-
PlatformInAppBrowserEvents
-
-
PlatformInAppLocalhostServer
-
This class allows you to create a simple server on
http://localhost:[port]/
in order to be able to load your assets file on a local server.
The default port value is 8080.
-
PlatformInAppLocalhostServerCreationParams
-
Object specifying creation parameters for creating a PlatformInAppLocalhostServer.
-
PlatformInAppWebViewController
-
Controls a WebView, such as an
InAppWebView widget instance, a HeadlessInAppWebView instance or PlatformInAppBrowser WebView instance.
-
PlatformInAppWebViewControllerCreationParams
-
Object specifying creation parameters for creating a PlatformInAppWebViewController.
-
PlatformInAppWebViewWidget
-
Interface for a platform implementation of a web view widget.
-
PlatformInAppWebViewWidgetCreationParams
-
Object specifying creation parameters for creating a PlatformInAppWebViewWidget.
-
PlatformInternalStoragePathHandler
-
Handler class to open files from application internal storage.
For more information about android storage please refer to
Android Developers Docs: Data and file storage overview.
-
PlatformInternalStoragePathHandlerCreationParams
-
Object specifying creation parameters for creating a PlatformInternalStoragePathHandler.
-
PlatformJavaScriptDelegate
-
Delegate for JavaScript-related methods of PlatformInAppWebViewController.
-
PlatformJavaScriptReplyProxy
-
This class represents the JavaScript object injected by PlatformInAppWebViewController.addWebMessageListener.
An instance will be given by PlatformWebMessageListener.onPostMessage.
The app can use
postMessage(String) to talk to the JavaScript context.
-
PlatformJavaScriptReplyProxyCreationParams
-
Object specifying creation parameters for creating a PlatformJavaScriptReplyProxy.
-
PlatformLocalStorage
-
Class that provides methods to manage the JavaScript
window.localStorage object.
It used by PlatformWebStorage.
-
PlatformLocalStorageCreationParams
-
Object specifying creation parameters for creating a PlatformLocalStorage.
-
PlatformNavigationDelegate
-
Delegate for navigation-related methods of PlatformInAppWebViewController.
-
PlatformPathHandler
-
A handler that produces responses for a registered path.
-
PlatformPathHandlerCreationParams
-
Object specifying creation parameters for creating a PlatformPathHandler.
-
PlatformPathHandlerEvents
-
Interface path handler events.
-
PlatformPrintJobController
-
Class representing a print job eventually returned by PlatformInAppWebViewController.printCurrentPage.
-
PlatformPrintJobControllerCreationParams
-
Object specifying creation parameters for creating a PlatformPrintJobController.
-
PlatformProcessGlobalConfig
-
Process Global Configuration for
WebView.
WebView has some process-global configuration parameters
that cannot be changed once WebView has been loaded.
This class allows apps to set these parameters.
-
PlatformProcessGlobalConfigCreationParams
-
Object specifying creation parameters for creating a PlatformProcessGlobalConfig.
-
PlatformProxyController
-
Manages setting and clearing a process-specific override for the Android/iOS system-wide proxy settings that govern network requests made
by
WebView/WKWebView
-
PlatformProxyControllerCreationParams
-
Object specifying creation parameters for creating a PlatformProxyController.
-
PlatformPullToRefreshController
-
A standard controller that can initiate the refreshing of a scroll view’s contents.
This should be used whenever the user can refresh the contents of a WebView via a vertical swipe gesture.
-
PlatformPullToRefreshControllerCreationParams
-
Object specifying creation parameters for creating a PlatformPullToRefreshController.
-
PlatformResourcesPathHandler
-
Handler class to open a file from resources directory in the application APK.
-
PlatformResourcesPathHandlerCreationParams
-
Object specifying creation parameters for creating a PlatformResourcesPathHandler.
-
PlatformServiceWorkerController
-
Class that manages Service Workers used by
WebView.
-
PlatformServiceWorkerControllerCreationParams
-
Object specifying creation parameters for creating a PlatformServiceWorkerController.
-
PlatformSessionStorage
-
Class that provides methods to manage the JavaScript
window.sessionStorage object.
It used by PlatformWebStorage.
-
PlatformSessionStorageCreationParams
-
Object specifying creation parameters for creating a PlatformSessionStorage.
-
PlatformSettingsDelegate
-
Delegate for reading and updating the WebView settings of a single
PlatformInAppWebViewController.
-
PlatformStorage
-
Class that provides methods to manage the JavaScript Storage object.
It is used by PlatformLocalStorage and PlatformSessionStorage.
-
PlatformStorageCreationParams
-
Object specifying creation parameters for creating a PlatformStorage.
-
PlatformTracingController
-
Manages tracing of
WebViews.
In particular provides functionality for the app to enable/disable tracing of parts of code and to collect tracing data.
This is useful for profiling performance issues, debugging and memory usage analysis in production and real life scenarios.
-
PlatformTracingControllerCreationParams
-
Object specifying creation parameters for creating a PlatformTracingController.
-
PlatformWebAuthenticationSession
-
A session that an app uses to authenticate a user through a web service.
-
PlatformWebAuthenticationSessionCreationParams
-
Object specifying creation parameters for creating a PlatformWebAuthenticationSession.
-
PlatformWebMessageChannel
-
Disposes the web message channel.
-
PlatformWebMessageChannelCreationParams
-
Object specifying creation parameters for creating a PlatformWebMessageChannel.
-
PlatformWebMessageListener
-
This listener receives messages sent on the JavaScript object which was injected by PlatformInAppWebViewController.addWebMessageListener.
-
PlatformWebMessageListenerCreationParams
-
Object specifying creation parameters for creating a PlatformWebMessageListener.
-
PlatformWebMessagePort
-
The representation of the HTML5 message ports.
-
PlatformWebMessagePortCreationParams
-
Object specifying creation parameters for creating a PlatformWebMessagePort.
-
PlatformWebStorage
-
Class that provides access to the JavaScript Web Storage API:
window.sessionStorage and window.localStorage.
It used by PlatformInAppWebViewController.webStorage.
-
PlatformWebStorageCreationParams
-
Object specifying creation parameters for creating a PlatformWebStorage.
-
PlatformWebStorageManager
-
Class that implements a singleton object (shared instance) which manages the web storage used by WebView instances.
On Android, it is implemented using WebStorage.
On iOS and MacOS, it is implemented using WKWebsiteDataStore.default().
-
PlatformWebStorageManagerCreationParams
-
Object specifying creation parameters for creating a PlatformWebStorageManager.
-
PlatformWebViewCreationParams<T>
-
Class that represents a WebView. Used by
InAppWebView, HeadlessInAppWebView and the WebView of PlatformInAppBrowser.
-
PlatformWebViewEnvironment
-
Controls a WebView Environment used by WebView instances.
Use dispose when not needed anymore to release references.
-
PlatformWebViewEnvironmentCreationParams
-
Object specifying creation parameters for creating a PlatformWebViewEnvironment.
-
PlatformWebViewFeature
-
Class that represents an Android-specific utility class for checking which WebView Support Library features are supported on the device.
-
PlatformWebViewFeatureCreationParams
-
Object specifying creation parameters for creating a PlatformWebViewFeature.
-
PrewarmingToken
-
-
Printer
-
-
PrintJobAttributes
-
-
PrintJobInfo
-
-
PrintJobMediaSize
-
-
PrintJobResolution
-
-
PrintJobSettings
-
-
ProcessGlobalConfigDirectoryBasePaths
-
-
ProcessGlobalConfigDirectoryBasePathsFields
-
Field descriptors for ProcessGlobalConfigDirectoryBasePaths query construction
-
ProcessGlobalConfigDirectoryBasePathsPatch
-
-
ProcessGlobalConfigSettings
-
-
ProcessGlobalConfigSettingsFields
-
Field descriptors for ProcessGlobalConfigSettings query construction
-
ProcessGlobalConfigSettingsPatch
-
-
ProxyRule
-
-
ProxySettings
-
Class that represents the settings used to configure the PlatformProxyController.
-
PullToRefreshSettings
-
-
RendererPriorityPolicy
-
-
RenderProcessGoneDetail
-
-
RequestFocusNodeHrefResult
-
-
RequestImageRefResult
-
-
ResourceType
-
The type of a captured network resource.
-
SafeBrowsingResponse
-
-
ScreenshotConfiguration
-
-
ScriptHtmlTagAttributes
-
Class that represents the possible the
<script> HTML attributes to be set used by PlatformInAppWebViewController.injectJavascriptFileFromUrl.
-
SecurityOrigin
-
-
ServerTrustAuthResponse
-
-
ServerTrustChallenge
-
Class that represents the challenge of the PlatformWebViewCreationParams.onReceivedServerTrustAuthRequest event.
It provides all the information about the challenge.
-
ServiceWorkerClient
-
Class used by clients to capture Service Worker related callbacks.
-
SslCertificate
-
Represents an SSL certificate.
-
SslCertificateDName
-
-
SslError
-
-
SubjectKeyIdentifierExtension
-
Recognition for Subject Key Identifier Extension (2.5.29.14)
-
TracingSettings
-
-
TrustedWebActivityDefaultDisplayMode
-
Class that represents the default display mode of a Trusted Web Activity.
The system UI (status bar, navigation bar) is shown, and the browser toolbar is hidden while the user is on a verified origin.
-
TrustedWebActivityDisplayMode
-
-
TrustedWebActivityImmersiveDisplayMode
-
Class that represents the default display mode of a Trusted Web Activity.
The system UI (status bar, navigation bar) is shown, and the browser toolbar is hidden while the user is on a verified origin.
-
UIEventAttribution
-
-
UIImage
-
-
URLAuthenticationChallenge
-
Class that represents a challenge from a server requiring authentication from the client.
It provides all the information about the challenge.
-
URLCredential
-
-
UrlPatternType
-
How URL patterns of the Network Capture API are interpreted.
-
URLProtectionSpace
-
-
URLProtectionSpaceHttpAuthCredentials
-
-
URLRequest
-
-
URLResponse
-
-
UserScript
-
-
Util
-
-
VirtualHostMapping
-
-
WebAuthenticationSessionSettings
-
-
WebHistory
-
-
WebHistoryItem
-
-
WebMessage
-
-
WebResourceError
-
-
WebResourceRequest
-
-
WebResourceResponse
-
-
WebsiteDataRecord
-
-
WebStorageItem
-
-
WebStorageOrigin
-
-
WebUri
-
Class that implements the Uri interface to maintain also the raw string value used by Uri.parse.
-
WebViewAssetLoader
-
-
WebViewAssetLoaderFields
-
Field descriptors for WebViewAssetLoader query construction
-
WebViewAssetLoaderPatch
-
-
WebViewEnvironmentSettings
-
-
WebViewPackageInfo
-
-
WindowFeatures
-
-
X509Certificate
-
Class that represents a X.509 certificate.
This provides a standard way to access all the attributes of an X.509 certificate.
-
X509Extension
-
-
X509PublicKey
-
Enums
-
Class used to disable the action mode menu items.
-
AjaxRequestAction
-
-
AjaxRequestEventType
-
-
AjaxRequestReadyState
-
-
AndroidProxySettings$
-
-
AttributedStringTextEffectStyle
-
Class that represents the supported proxy types.
-
CacheMode
-
Class used to override the way the cache is used.
-
ClientCertResponseAction
-
Class used by ClientCertResponse class.
-
CompressFormat
-
Class that represents the known formats a bitmap can be compressed into.
-
ConsoleMessageLevel
-
-
ContentBlockerActionType
-
Class that represents the kind of action that can be used with a ContentBlockerTrigger.
-
ContentBlockerTriggerLoadContext
-
Class that represents the kind of load context that can be used with a ContentBlockerTrigger.
-
ContentBlockerTriggerLoadType
-
Class that represents the possible load type for a ContentBlockerTrigger.
-
ContentBlockerTriggerResourceType
-
Class that represents the possible resource type defined for a ContentBlockerTrigger.
-
CrossOrigin
-
Class that represents the
crossorigin content attribute on media elements, which is a CORS settings attribute.
It could be used with ScriptHtmlTagAttributes and CSSLinkHtmlTagAttributes
when fetching a resource <link> or a <script> (or resources fetched by the <script>).
-
CustomTabsNavigationEventType
-
The type corresponding to the navigation event of PlatformChromeSafariBrowserEvents.onNavigationEvent.
-
CustomTabsPostMessageResultType
-
Custom Tabs postMessage result type.
-
CustomTabsRelationType
-
Custom Tabs relation for which the result is available.
-
CustomTabsShareState
-
Class representing the share state that should be applied to the custom tab.
-
DataDetectorTypes
-
Class used to specify a
dataDetectoryTypes value that adds interactivity to web content that matches the value.
-
DismissButtonStyle
-
Class used to set the custom style for the dismiss button.
-
FetchRequestAction
-
-
ForceDark
-
Class used to indicate the force dark mode.
-
ForceDarkStrategy
-
Class used to indicate how
WebView content should be darkened.
-
FormResubmissionAction
-
Class that represents the action to take used by the PlatformWebViewCreationParams.onFormResubmission event.
-
HostResourceAccessKind
-
The access kind for resources mapped by VirtualHostMapping.
-
HttpAuthResponseAction
-
Class used by HttpAuthResponse class.
-
HTTPCookieSameSitePolicy
-
Class that represents the same site policy of a cookie. Used by the Cookie class.
-
InAppWebViewHitTestResultType
-
Class representing the InAppWebViewHitTestResult type.
-
IOSProxySettings$
-
-
JsAlertResponseAction
-
-
JsBeforeUnloadResponseAction
-
-
JsConfirmResponseAction
-
-
JsPromptResponseAction
-
-
LayoutAlgorithm
-
Class used to set the underlying layout algorithm.
-
LayoutInDisplayCutoutMode
-
Class representing the share state that should be applied to the custom tab.
-
MediaCaptureState
-
Class that describes whether a media device, like a camera or microphone, is currently capturing audio or video.
-
MediaPlaybackState
-
Class that describes whether an audio or video presentation is playing, paused, or suspended.
-
MixedContentMode
-
Class used to configure the WebView's behavior when a secure origin attempts to load a resource from an insecure origin.
-
ModalPresentationStyle
-
Class used to specify the modal presentation style when presenting a view controller.
-
ModalTransitionStyle
-
Class used to specify the transition style when presenting a view controller.
-
NavigationActionPolicy
-
Class that is used by PlatformWebViewCreationParams.shouldOverrideUrlLoading event.
It represents the policy to pass back to the decision handler.
-
NavigationResponseAction
-
Class that is used by PlatformWebViewCreationParams.onNavigationResponse event.
It represents the policy to pass back to the decision handler.
-
NavigationType
-
Class that represents the type of action triggering a navigation for the PlatformWebViewCreationParams.shouldOverrideUrlLoading event.
-
OverScrollMode
-
Class used to configure the
WebView's over-scroll mode.
Setting the over-scroll mode of a WebView will have an effect only if the WebView is capable of scrolling.
-
PermissionResourceType
-
-
PermissionResponseAction
-
-
PrintJobColorMode
-
Class representing how the printed content of a PlatformPrintJobController should be laid out.
-
PrintJobDisposition
-
Class representing the constants that specify values for the print job disposition of a PlatformPrintJobController.
-
PrintJobDuplexMode
-
Class representing the orientation of a PlatformPrintJobController.
-
PrintJobOrientation
-
Class representing the orientation of a PlatformPrintJobController.
-
PrintJobOutputType
-
Class representing the kind of printable content of a PlatformPrintJobController.
-
PrintJobPageOrder
-
Class representing the page order that will be used to generate the pages of a PlatformPrintJobController.
-
Class representing the constants that specify the different ways in which an image is divided into pages of a PlatformPrintJobController.
-
PrintJobRenderingQuality
-
Class representing the rendering quality of a PlatformPrintJobController.
-
PrintJobState
-
Class representing the state of a PlatformPrintJobController.
-
ProcessGlobalConfigDirectoryBasePaths$
-
-
ProcessGlobalConfigSettings$
-
-
ProxySchemeFilter
-
Class that represent scheme filters used by PlatformProxyController.
-
PullToRefreshSize
-
Class representing the size of the refresh indicator.
-
ReferrerPolicy
-
Class that represents a Referrer-Policy HTTP header.
It could be used with ScriptHtmlTagAttributes and CSSLinkHtmlTagAttributes
when fetching a resource
<link> or a <script> (or resources fetched by the <script>).
-
RendererPriority
-
Class used by RendererPriorityPolicy class.
-
SafeBrowsingResponseAction
-
-
SafeBrowsingThreat
-
-
Sandbox
-
Class that describes what to allow in the iframe.
-
ScrollBarStyle
-
Class used to configure the style of the scrollbars.
The scrollbars can be overlaid or inset.
When inset, they add to the padding of the view. And the scrollbars can be drawn inside the padding area or on the edge of the view.
For example, if a view has a background drawable and you want to draw the scrollbars inside the padding specified by the drawable,
you can use ScrollBarStyle.SCROLLBARS_INSIDE_OVERLAY or ScrollBarStyle.SCROLLBARS_INSIDE_INSET.
If you want them to appear at the edge of the view, ignoring the padding,
then you can use ScrollBarStyle.SCROLLBARS_OUTSIDE_OVERLAY or ScrollBarStyle.SCROLLBARS_OUTSIDE_INSET.
-
ScrollViewContentInsetAdjustmentBehavior
-
Class used to configure how safe area insets are added to the adjusted content inset.
-
ScrollViewDecelerationRate
-
Class that represents a floating-point value that determines the rate of deceleration after the user lifts their finger.
-
SearchResultDisplayStyle
-
Constants that describe the results summary the find panel UI includes.
-
SelectionGranularity
-
Class used to set the level of granularity with which the user can interactively select content in the web view.
-
ServerTrustAuthResponseAction
-
Class used by ServerTrustAuthResponse class.
-
ShouldAllowDeprecatedTLSAction
-
Class that is used by PlatformWebViewCreationParams.shouldAllowDeprecatedTLS event.
It represents the policy to pass back to the decision handler.
-
SslErrorType
-
Class that represents the SSL Primary error associated to the server SSL certificate.
Used by the ServerTrustChallenge class.
-
TracingCategory
-
Constants that describe the results summary the find panel UI includes.
-
TracingMode
-
Constants that describe the results summary the find panel UI includes.
-
TrustedWebActivityScreenOrientation
-
Class representing Screen Orientation Lock type value of a Trusted Web Activity:
https://www.w3.org/TR/screen-orientation/#screenorientation-interface
-
UnderlineStyle
-
Class that represents the constants for the underline style and strikethrough style attribute keys.
-
URLCredentialPersistence
-
Class that represents the constants that specify how long the credential will be kept.
-
URLProtectionSpaceAuthenticationMethod
-
Class that represents the constants describing known values of the URLProtectionSpace.authenticationMethod property.
-
URLProtectionSpaceProxyType
-
Class that represents the supported proxy types.
-
URLRequestAttribution
-
Class that represents the constants used to indicate the entities that can make a network request.
-
URLRequestCachePolicy
-
Class that represents the constants used to specify interaction with the cached responses.
-
URLRequestNetworkServiceType
-
Class that represents the constants that specify how a request uses network resources.
-
UserPreferredContentMode
-
Class that represents the content mode to prefer when loading and rendering a webpage.
-
UserScriptInjectionTime
-
Class that represents contains the constants for the times at which to inject script content into a
WebView used by an UserScript.
-
VerticalScrollbarPosition
-
Class used to configure the position of the vertical scroll bar.
-
WebArchiveFormat
-
Class that represents the known Web Archive formats used when saving a web page.
-
WebAuthenticationSessionError
-
Class that represents the error code for a web authentication session error.
-
WebAuthenticationSupport
-
Class that describes the Web Authentication support level for a WebView instance.
-
WebMessageType
-
The type corresponding to the WebMessage.
-
WebResourceErrorType
-
-
WebsiteDataType
-
Class that represents a website data type.
-
WebStorageType
-
Class that represents the type of Web Storage:
localStorage or sessionStorage.
Used by the PlatformStorage class.
-
WebViewAssetLoader$
-
-
WebViewFeature
-
Class that represents an Android-specific utility class for checking which WebView Support Library features are supported on the device.
-
WebViewRenderProcessAction
-
Class that represents the action to take used by the PlatformWebViewCreationParams.onRenderProcessUnresponsive and PlatformWebViewCreationParams.onRenderProcessResponsive event
to terminate the Android WebViewRenderProcess.
-
WindowStyleMask
-
Class that represents the flags that describe the browser window’s current style, such as if it’s resizable or in full-screen mode.
-
WindowTitlebarSeparatorStyle
-
Class that represents the type of separator that the app displays between the title bar and content of a browser window.
-
WindowType
-
Class that represents how a browser window should be added to the main window.
-
X509BlockPosition
-
Functions
-
-
-
attributedStringTextEffectStyleFromWire(Object? value)
→ AttributedStringTextEffectStyle?
-
-
attributedStringTextEffectStyleToWire(AttributedStringTextEffectStyle? value)
→ Object?
-
-
cacheModeFromWire(Object? value)
→ CacheMode?
-
-
cacheModeToWire(CacheMode? value)
→ Object?
-
-
contentBlockerActionTypeFromWire(String? value)
→ ContentBlockerActionType?
-
-
contentBlockerActionTypeToWire(ContentBlockerActionType? value)
→ String?
-
-
contentBlockerTriggerLoadContextFromWire(String? value)
→ ContentBlockerTriggerLoadContext?
-
-
contentBlockerTriggerLoadContextToWire(ContentBlockerTriggerLoadContext? value)
→ String?
-
-
contentBlockerTriggerLoadTypeFromWire(String? value)
→ ContentBlockerTriggerLoadType?
-
-
contentBlockerTriggerLoadTypeToWire(ContentBlockerTriggerLoadType? value)
→ String?
-
-
contentBlockerTriggerResourceTypeFromWire(String? value)
→ ContentBlockerTriggerResourceType?
-
-
contentBlockerTriggerResourceTypeToWire(ContentBlockerTriggerResourceType? value)
→ String?
-
-
customTabsNavigationEventTypeFromWire(Object? value)
→ CustomTabsNavigationEventType?
-
-
customTabsNavigationEventTypeToWire(CustomTabsNavigationEventType? value)
→ Object?
-
-
customTabsPostMessageResultTypeFromWire(Object? value)
→ CustomTabsPostMessageResultType?
-
-
customTabsPostMessageResultTypeToWire(CustomTabsPostMessageResultType? value)
→ Object?
-
-
customTabsRelationTypeFromWire(Object? value)
→ CustomTabsRelationType?
-
-
customTabsRelationTypeToWire(CustomTabsRelationType? value)
→ Object?
-
-
debugLog({required DebugLoggingSettings debugLoggingSettings, required String className, required String method, String? name, String? id, dynamic args})
→ void
-
-
firstLeafValue({required ASN1Object block})
→ dynamic
-
-
formResubmissionActionFromWire(Object? value)
→ FormResubmissionAction?
-
FormResubmissionAction wire values are sequential 0..n-1 —
.index matches.
-
formResubmissionActionToWire(FormResubmissionAction? value)
→ Object?
-
-
httpCookieSameSitePolicyFromWire(Object? value)
→ HTTPCookieSameSitePolicy?
-
-
httpCookieSameSitePolicyToWire(HTTPCookieSameSitePolicy? value)
→ Object?
-
-
inAppWebViewHitTestResultTypeFromWire(Object? value)
→ InAppWebViewHitTestResultType?
-
-
inAppWebViewHitTestResultTypeToWire(InAppWebViewHitTestResultType? value)
→ Object?
-
-
mediaCaptureStateFromWire(Object? value)
→ MediaCaptureState?
-
MediaCaptureState wire values are sequential 0..n-1 —
.index matches.
-
mediaCaptureStateToWire(MediaCaptureState? value)
→ Object?
-
-
mediaPlaybackStateFromWire(Object? value)
→ MediaPlaybackState?
-
MediaPlaybackState wire values are sequential 0..n-1 —
.index matches.
-
mediaPlaybackStateToWire(MediaPlaybackState? value)
→ Object?
-
-
printJobColorModeFromWire(int? value)
→ PrintJobColorMode?
-
PrintJobColorMode wire values are 1-based (MONOCHROME=1, COLOR=2) — a
plain enum's
.index is offset by one.
-
printJobColorModeToWire(PrintJobColorMode? mode)
→ int?
-
-
printJobPageOrderFromWire(int? value)
→ PrintJobPageOrder?
-
-
printJobPageOrderToWire(PrintJobPageOrder? pageOrder)
→ int?
-
-
printJobStateFromWire(int? value)
→ PrintJobState?
-
PrintJobState wire values are 1-based (CREATED=1 .. CANCELED=7) — a plain
enum's
.index is offset by one.
-
printJobStateToWire(PrintJobState? state)
→ int?
-
-
proxySchemeFilterFromWire(Object? value)
→ ProxySchemeFilter?
-
-
proxySchemeFilterToWire(ProxySchemeFilter? value)
→ Object?
-
-
pullToRefreshSizeToWire(PullToRefreshSize size)
→ int
-
PullToRefreshSize wire values are NOT sequential (DEFAULT=1, LARGE=0 in
the old codegen) — a plain enum's
.index would be reversed.
-
toIntValue(List<int> data)
→ BigInt?
-
-
tracingCategoryFromWire(Object? value)
→ TracingCategory?
-
-
tracingCategoryToWire(TracingCategory? value)
→ Object?
-
-
underlineStyleFromWire(Object? value)
→ UnderlineStyle?
-
-
underlineStyleToWire(UnderlineStyle? value)
→ Object?
-
-
webArchiveFormatFromWire(Object? value)
→ WebArchiveFormat?
-
-
webArchiveFormatToWire(WebArchiveFormat? value)
→ Object?
-
-
webAuthenticationSessionErrorFromWire(int? value)
→ WebAuthenticationSessionError?
-
WebAuthenticationSessionError wire values are 1-based (CANCELED_LOGIN=1,
PRESENTATION_CONTEXT_NOT_PROVIDED=2, PRESENTATION_CONTEXT_INVALID=3) — a
plain enum's
.index is offset by one.
-
webAuthenticationSessionErrorToWire(WebAuthenticationSessionError? error)
→ int?
-
-
webAuthenticationSupportFromWire(Object? value)
→ WebAuthenticationSupport?
-
-
webAuthenticationSupportToWire(WebAuthenticationSupport? value)
→ Object?
-
-
websiteDataTypeFromWire(Object? value)
→ WebsiteDataType?
-
-
websiteDataTypeToWire(WebsiteDataType? value)
→ Object?
-
-
webStorageTypeToWire(WebStorageType type)
→ String
-
WebStorageType wire values are the JS storage names (the old
_value),
which differ from the member names — lookup by value.
-
webViewRenderProcessActionFromWire(Object? value)
→ WebViewRenderProcessAction?
-
WebViewRenderProcessAction wire values are sequential 0..n-1 —
.index matches.
-
webViewRenderProcessActionToWire(WebViewRenderProcessAction? value)
→ Object?
-
-
windowStyleMaskFromWire(Object? value)
→ WindowStyleMask?
-
-
windowStyleMaskToWire(WindowStyleMask? value)
→ Object?
-