CrossOrigin enum
Class that represents the crossorigin content attribute on media elements, which is a CORS settings attribute.
It could be used with ScriptHtmlTagAttributes and CSSLinkHtmlTagAttributes
when fetching a resource <link> or a <script> (or resources fetched by the <script>).
Values
- ANONYMOUS → const CrossOrigin
-
CORS requests for this element will have the credentials flag set to 'same-origin'.
- USE_CREDENTIALS → const CrossOrigin
-
CORS requests for this element will have the credentials flag set to 'include'.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CrossOrigin> - A constant List of the values in this enum, in order of their declaration.