URLRequestAttribution enum
Class that represents the constants used to indicate the entities that can make a network request.
Values
- DEVELOPER → const URLRequestAttribution
-
A developer-initiated network request.
Use this value for the attribution parameter of a URLRequest that your app makes for any purpose other than when the user explicitly accesses a link. This includes requests that your app makes to get user data. This is the default value.
For cases where the user enters a URL, like in the navigation bar of a web browser, or taps or clicks a URL to load the content it represents, use the URLRequestAttribution.USER value instead.
- USER → const URLRequestAttribution
-
Use this value for the attribution parameter of a URLRequest that satisfies a user request to access an explicit, unmodified URL. In all other cases, use the URLRequestAttribution.DEVELOPER value instead.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
URLRequestAttribution> - A constant List of the values in this enum, in order of their declaration.